tensap.functions.polynomials package
====================================

Submodules
----------

tensap.functions.polynomials.orthonormal\_polynomials module
------------------------------------------------------------

.. automodule:: tensap.functions.polynomials.orthonormal_polynomials
   :members:
   :undoc-members:
   :show-inheritance:

tensap.functions.polynomials.polynomials module
-----------------------------------------------

.. automodule:: tensap.functions.polynomials.polynomials
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tensap.functions.polynomials
   :members:
   :undoc-members:
   :show-inheritance:
